==> formant-1.230.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/auth/auth_controller_forgot_password.py <==
from http import HTTPStatus
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.forgot_password_request import ForgotPasswordRequest
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ForgotPasswordRequest,
) -> Dict[str, Any]:
    url = "{}/auth/forgot-password".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ForgotPasswordRequest,
) -> Response[Any]:
    """Forgot password

     Initiate the 'forgot password?' workflow.

    Args:
        json_body (ForgotPasswordRequest):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: ForgotPasswordRequest,
) -> Response[Any]:
    """Forgot password

     Initiate the 'forgot password?' workflow.

    Args:
        json_body (ForgotPasswordRequest):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> formant-1.268.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/auth/auth_controller_forgot_password.py <==
from http import HTTPStatus
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.forgot_password_request import ForgotPasswordRequest
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: ForgotPasswordRequest,

) -> Dict[str, Any]:
    url = "{}/auth/forgot-password".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }




def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    json_body: ForgotPasswordRequest,

) -> Response[Any]:
    """Forgot password

     Initiate the 'forgot password?' workflow.

    Args:
        json_body (ForgotPasswordRequest):

    Returns:
        Response[Any]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    json_body: ForgotPasswordRequest,

) -> Response[Any]:
    """Forgot password

     Initiate the 'forgot password?' workflow.

    Args:
        json_body (ForgotPasswordRequest):

    Returns:
        Response[Any]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(response=response)
